@@ -34,7 +34,6 @@ class _StreamHandlerWrapper(socketserver.StreamRequestHandler):
 
     def setup(self):
         super().setup()
-        # pylint: disable=no-member
         self.delegate = self.DELEGATE_CLASS(self.rfile, self.wfile)
 
     def handle(self):
@@ -48,7 +47,6 @@ class _StreamHandlerWrapper(socketserver.StreamRequestHandler):
                 if isinstance(e, WindowsError) and e.winerror == 10054:
                     pass
 
-        # pylint: disable=no-member
         self.SHUTDOWN_CALL()
 
 
@@ -212,6 +210,8 @@ class PythonLSPServer(MethodDispatcher):
         raise KeyError()
 
     def m_shutdown(self, **_kwargs):
+        for workspace in self.workspaces.values():
+            workspace.close()
         self._shutdown = True
 
     def m_exit(self, **_kwargs):
@@ -351,6 +351,9 @@ class PythonLSPServer(MethodDispatcher):
     def document_symbols(self, doc_uri):
         return flatten(self._hook('pylsp_document_symbols', doc_uri))
 
+    def document_did_save(self, doc_uri):
+        return self._hook("pylsp_document_did_save", doc_uri)
+
     def execute_command(self, command, arguments):
         return self._hook('pylsp_execute_command', command=command, arguments=arguments)
 
@@ -417,6 +420,7 @@ class PythonLSPServer(MethodDispatcher):
 
     def m_text_document__did_save(self, textDocument=None, **_kwargs):
         self.lint(textDocument['uri'], is_saved=True)
+        self.document_did_save(textDocument['uri'])
 
     def m_text_document__code_action(self, textDocument=None, range=None, context=None, **_kwargs):
         return self.code_actions(textDocument['uri'], range, context)
