@@ -19,7 +19,7 @@ def test_mccabe(config, workspace):
     try:
         config.update({'plugins': {'mccabe': {'threshold': 1}}})
         doc = Document(DOC_URI, workspace, DOC)
-        diags = mccabe_lint.pylsp_lint(config, doc)
+        diags = mccabe_lint.pylsp_lint(config, workspace, doc)
 
         assert all(d['source'] == 'mccabe' for d in diags)
 
@@ -36,4 +36,4 @@ def test_mccabe(config, workspace):
 
 def test_mccabe_syntax_error(config, workspace):
     doc = Document(DOC_URI, workspace, DOC_SYNTAX_ERR)
-    assert mccabe_lint.pylsp_lint(config, doc) is None
+    assert mccabe_lint.pylsp_lint(config, workspace, doc) is None
