@@ -30,7 +30,7 @@ import sys
 
 def test_pyflakes(workspace):
     doc = Document(DOC_URI, workspace, DOC)
-    diags = pyflakes_lint.pylsp_lint(doc)
+    diags = pyflakes_lint.pylsp_lint(workspace, doc)
 
     # One we're expecting is:
     msg = '\'sys\' imported but unused'
@@ -42,7 +42,7 @@ def test_pyflakes(workspace):
 
 def test_syntax_error_pyflakes(workspace):
     doc = Document(DOC_URI, workspace, DOC_SYNTAX_ERR)
-    diag = pyflakes_lint.pylsp_lint(doc)[0]
+    diag = pyflakes_lint.pylsp_lint(workspace, doc)[0]
 
     if sys.version_info[:2] >= (3, 10):
         assert diag['message'] == "expected ':'"
@@ -54,7 +54,7 @@ def test_syntax_error_pyflakes(workspace):
 
 def test_undefined_name_pyflakes(workspace):
     doc = Document(DOC_URI, workspace, DOC_UNDEFINED_NAME_ERR)
-    diag = pyflakes_lint.pylsp_lint(doc)[0]
+    diag = pyflakes_lint.pylsp_lint(workspace, doc)[0]
 
     assert diag['message'] == 'undefined name \'b\''
     assert diag['range']['start'] == {'line': 0, 'character': 4}
@@ -63,7 +63,7 @@ def test_undefined_name_pyflakes(workspace):
 
 def test_unicode_encoding(workspace):
     doc = Document(DOC_URI, workspace, DOC_ENCODING)
-    diags = pyflakes_lint.pylsp_lint(doc)
+    diags = pyflakes_lint.pylsp_lint(workspace, doc)
 
     assert len(diags) == 1
     assert diags[0]['message'] == '\'sys\' imported but unused'
